@@ -164,6 +164,11 @@ public class AsyncHttpClientTypesafeConfig implements AsyncHttpClientConfig {
     return new ThreadSafeCookieStore();
   }
 
+  @Override
+  public int expiredCookieEvictionDelay() {
+    return getIntegerOpt(EXPIRED_COOKIE_EVICTION_DELAY).orElse(defaultExpiredCookieEvictionDelay());
+  }
+
   @Override
   public int getMaxRequestRetry() {
     return getIntegerOpt(MAX_REQUEST_RETRY_CONFIG).orElse(defaultMaxRequestRetry());
@@ -339,6 +344,16 @@ public class AsyncHttpClientTypesafeConfig implements AsyncHttpClientConfig {
     return null;
   }
 
+  @Override
+  public long getHashedWheelTimerTickDuration() {
+    return getIntegerOpt(HASHED_WHEEL_TIMER_TICK_DURATION).orElse(defaultHashedWheelTimerTickDuration());
+  }
+
+  @Override
+  public int getHashedWheelTimerSize() {
+    return getIntegerOpt(HASHED_WHEEL_TIMER_SIZE).orElse(defaultHashedWheelTimerSize());
+  }
+
   @Override
   public KeepAliveStrategy getKeepAliveStrategy() {
     return new DefaultKeepAliveStrategy();
